<?php declare(strict_types=1);

namespace Everyware\Widget\ArticleList;

use Everyware\ProjectPlugin\Components\Contracts\InfoManager;
use Everyware\ProjectPlugin\Components\WidgetSettingsForm;
use Infomaker\Everyware\Base\Pages;
use Infomaker\Everyware\Base\Templates;
use Infomaker\Everyware\Support\Str;
use Infomaker\Everyware\Twig\View;
use OcAPI;

class ArticleListForm extends WidgetSettingsForm
{
    /**
     * @var OcAPI
     */
    private $ocApi;

    public function __construct(InfoManager $infoManager, OcAPI $ocApi)
    {
        $this->ocApi = $ocApi;
        parent::__construct($infoManager);
    }

    /**
     * @param $storedData
     *
     * @return string
     */
    protected function formContent($storedData): string
    {
        return View::generate('@widgets/form', array_replace($this->generateViewData($storedData), [
            'pages' => Pages::getSelectData(),
            'templates' => Templates::getSelectData(),
            'sortings' => $this->sortingsSelectData(),
            'settings' => $this->getFormSettings(),
            'form' => $this->generateFormBuilder()
        ]));
    }

    /**
     * Function to get available contenttypes options
     *
     * @since 0.1
     * @return array
     */
    protected function contenttypesSelectData(): array
    {
        return array_map(function ($contenttype) {
            return [
                'value' => $contenttype,
                'text' => $contenttype
            ];
        }, array_keys($this->ocApi->get_content_types()));
    }

    /**
     * Function to get available properties from a contenttype as select-data
     *
     * @param string $contenttype
     *
     * @since 0.1
     * @return array
     */
    protected function propertiesSelectData($contenttype = 'Article'): array
    {
        $query_options = $this->ocApi->get_content_types();

        $properties = [];
        foreach ($query_options[$contenttype] as $property) {
            $property = $property[0] ?? '';
            if ( ! Str::isEmpty($property)) {
                $properties[] = [
                    'value' => $property,
                    'text' => Str::ucfirst($property)
                ];
            }
        }

        return $properties;
    }

    /**
     * Function to get available sort options
     *
     * @return array
     */
    protected function sortingsSelectData(): array
    {
        $sort_options = $this->ocApi->get_oc_sort_options();

        if (isset($sort_options->sortings)) {
            return array_map(function ($option) {
                return [
                    'value' => $option->name,
                    'text' => $option->name
                ];
            }, $sort_options->sortings);
        }

        return [];
    }
}
